@@ -7,7 +7,8 @@ our $es;
 my $r;
 
 ###  DELETE_BY_QUERY ###
-ok $es->delete_by_query( term => { text => 'foo' } )->{ok}, "Delete by query";
+ok $es->delete_by_query( query => { term => { text => 'foo' } } )->{ok},
+    "Delete by query";
 wait_for_es();
 
 is $es->count( term => { text => 'foo' } )->{count}, 0, " - foo deleted";
